@@ -35,6 +35,8 @@ from label_studio_tools.core.utils.io import get_local_path
 
 logger = logging.getLogger(__name__)
 
+LABEL_STUDIO_ML_BACKEND_V2_DEFAULT = False
+
 @attr.s
 class ModelWrapper(object):
     model = attr.ib()
@@ -444,24 +446,40 @@ class LabelStudioMLManager(object):
 
     @classmethod
     def has_active_model(cls, project):
-        return cls._key(project) in cls._current_model
+        if not os.getenv('LABEL_STUDIO_ML_BACKEND_V2', default=LABEL_STUDIO_ML_BACKEND_V2_DEFAULT):
+        # TODO: Deprecated branch since LS 1.5
+            return cls._key(project) in cls._current_model
+        else:
+            return cls._current_model is not None
 
     @classmethod
     def get(cls, project):
-        key = cls._key(project)
-        logger.debug('Get project ' + str(key))
-        return cls._current_model.get(key)
+        if not os.getenv('LABEL_STUDIO_ML_BACKEND_V2', default=LABEL_STUDIO_ML_BACKEND_V2_DEFAULT):
+        # TODO: Deprecated branch since LS 1.5
+            key = cls._key(project)
+            logger.debug('Get project ' + str(key))
+            return cls._current_model.get(key)
+        else:
+            return cls._current_model
 
     @classmethod
     def create(cls, project=None, label_config=None, train_output=None, version=None, **kwargs):
         key = cls._key(project)
         logger.debug('Create project ' + str(key))
         kwargs.update(cls.init_kwargs)
-        cls._current_model[key] = ModelWrapper(
-            model=cls.model_class(label_config=label_config, train_output=train_output, **kwargs),
-            model_version=version or cls._generate_version()
-        )
-        return cls._current_model[key]
+        if not os.getenv('LABEL_STUDIO_ML_BACKEND_V2', default=LABEL_STUDIO_ML_BACKEND_V2_DEFAULT):
+            # TODO: Deprecated branch since LS 1.5
+            cls._current_model[key] = ModelWrapper(
+                model=cls.model_class(label_config=label_config, train_output=train_output, **kwargs),
+                model_version=version or cls._generate_version()
+            )
+            return cls._current_model[key]
+        else:
+            cls._current_model = ModelWrapper(
+                model=cls.model_class(label_config=label_config, train_output=train_output, **kwargs),
+                model_version=version or cls._generate_version()
+            )
+            return cls._current_model
 
     @classmethod
     def get_or_create(
@@ -476,8 +494,8 @@ class LabelStudioMLManager(object):
 
     @classmethod
     def fetch(cls, project=None, label_config=None, force_reload=False, **kwargs):
-        if not os.getenv('LABEL_STUDIO_ML_BACKEND_V2', default=True):
-            # TODO: Deprecated branch
+        if not os.getenv('LABEL_STUDIO_ML_BACKEND_V2', default=LABEL_STUDIO_ML_BACKEND_V2_DEFAULT):
+            # TODO: Deprecated branch since LS 1.5
             if cls.without_redis():
                 logger.debug('Fetch ' + project + ' from local directory')
                 job_result = cls._get_latest_job_result_from_workdir(project) or {}
@@ -554,7 +572,7 @@ class LabelStudioMLManager(object):
     def predict(
         cls, tasks, project=None, label_config=None, force_reload=False, try_fetch=True, **kwargs
     ):
-        if not os.getenv('LABEL_STUDIO_ML_BACKEND_V2', default=True):
+        if not os.getenv('LABEL_STUDIO_ML_BACKEND_V2', default=LABEL_STUDIO_ML_BACKEND_V2_DEFAULT):
             if try_fetch:
                 m = cls.fetch(project, label_config, force_reload)
             else:
